@@ -21,32 +21,32 @@
 #include "fileops.h"
 #include "config-ktorrent.h"
 
-#include <string>
 #include <cstdlib>
-#include <unistd.h>
 #include <errno.h>
+#include <fcntl.h>
+#include <string>
 #include <sys/stat.h>
 #include <sys/types.h>
-#include <fcntl.h>
+#include <unistd.h>
 
 #include <QDir>
 #include <QFile>
 #include <QSet>
 #include <QStringList>
 
-#include <KLocalizedString>
-#include <KIO/Job>
 #include <KIO/CopyJob>
+#include <KIO/Job>
+#include <KLocalizedString>
 #include <Solid/Device>
 #include <Solid/StorageAccess>
 #include <Solid/StorageDrive>
 #include <Solid/StorageVolume>
 
-#include "error.h"
-#include "log.h"
-#include "file.h"
 #include "array.h"
+#include "error.h"
+#include "file.h"
 #include "functions.h"
+#include "log.h"
 #ifdef Q_WS_WIN
 #include "win32.h"
 #endif
@@ -68,11 +68,11 @@
 #endif
 
 #ifndef HAVE___U64
-typedef uint64_t    __u64;
+typedef uint64_t __u64;
 #endif
 
 #ifndef HAVE___S64
-typedef int64_t     __s64;
+typedef int64_t __s64;
 #endif
 
 #include <xfs/xfs.h>
@@ -83,25 +83,23 @@ typedef int64_t     __s64;
 #endif
 
 #ifndef Q_WS_WIN
-# ifdef Q_OS_LINUX
-# include <mntent.h>
-# endif
+#ifdef Q_OS_LINUX
+#include <mntent.h>
+#endif
 #include <sys/statvfs.h>
 #endif
 #ifdef CopyFile
 #undef CopyFile
 #endif
 
-
 namespace bt
 {
-void MakeDir(const QString & dir, bool nothrow)
+void MakeDir(const QString &dir, bool nothrow)
 {
     QDir d(dir);
     if (d.exists())
         return;
 
-
     QString n = d.dirName();
     if (!d.cdUp() || !d.mkdir(n)) {
         QString error = i18n("Cannot create directory %1", dir);
@@ -111,7 +109,7 @@ void MakeDir(const QString & dir, bool nothrow)
     }
 }
 
-void MakePath(const QString & dir, bool nothrow)
+void MakePath(const QString &dir, bool nothrow)
 {
     QStringList sl = dir.split(bt::DirSeparator(), Qt::SkipEmptyParts);
     QString ctmp;
@@ -135,7 +133,7 @@ void MakePath(const QString & dir, bool nothrow)
     }
 }
 
-void MakeFilePath(const QString & file, bool nothrow)
+void MakeFilePath(const QString &file, bool nothrow)
 {
     QStringList sl = file.split(bt::DirSeparator());
     QString ctmp;
@@ -145,7 +143,8 @@ void MakeFilePath(const QString & file, bool nothrow)
 
     for (int i = 0; i < sl.count() - 1; i++) {
         ctmp += sl[i];
-        if (!bt::Exists(ctmp)) try {
+        if (!bt::Exists(ctmp))
+            try {
                 MakeDir(ctmp, false);
             } catch (...) {
                 if (!nothrow)
@@ -157,76 +156,57 @@ void MakeFilePath(const QString & file, bool nothrow)
     }
 }
 
-void SymLink(const QString & link_to, const QString & link_url, bool nothrow)
+void SymLink(const QString &link_to, const QString &link_url, bool nothrow)
 {
     if (symlink(QFile::encodeName(link_to).constData(), QFile::encodeName(link_url).constData()) != 0) {
         if (!nothrow)
-            throw Error(i18n("Cannot symlink %1 to %2: %3"
-                             , link_url, link_to
-                             , QString::fromUtf8(strerror(errno))));
+            throw Error(i18n("Cannot symlink %1 to %2: %3", link_url, link_to, QString::fromUtf8(strerror(errno))));
         else
-            Out(SYS_DIO | LOG_NOTICE) << QStringLiteral("Error : Cannot symlink %1 to %2: %3")
-                                      .arg(link_url).arg(link_to)
-                                      .arg(QString::fromUtf8(strerror(errno))) << endl;
+            Out(SYS_DIO | LOG_NOTICE)
+                << QStringLiteral("Error : Cannot symlink %1 to %2: %3").arg(link_url).arg(link_to).arg(QString::fromUtf8(strerror(errno))) << endl;
     }
 }
 
-void Move(const QString & src, const QString & dst, bool nothrow, bool silent)
+void Move(const QString &src, const QString &dst, bool nothrow, bool silent)
 {
     //  Out() << "Moving " << src << " -> " << dst << endl;
-    KIO::CopyJob *mv = KIO::move(QUrl::fromLocalFile(src), QUrl::fromLocalFile(dst),
-                                 silent ? KIO::HideProgressInfo | KIO::Overwrite : KIO::DefaultFlags);
+    KIO::CopyJob *mv = KIO::move(QUrl::fromLocalFile(src), QUrl::fromLocalFile(dst), silent ? KIO::HideProgressInfo | KIO::Overwrite : KIO::DefaultFlags);
     if (!mv->exec()) {
         if (!nothrow)
-            throw Error(i18n("Cannot move %1 to %2: %3",
-                             src, dst,
-                             mv->errorString()));
+            throw Error(i18n("Cannot move %1 to %2: %3", src, dst, mv->errorString()));
         else
-            Out(SYS_DIO | LOG_NOTICE) << QStringLiteral("Error : Cannot move %1 to %2: %3")
-                                      .arg(src).arg(dst)
-                                      .arg(mv->errorString()) << endl;
-
+            Out(SYS_DIO | LOG_NOTICE) << QStringLiteral("Error : Cannot move %1 to %2: %3").arg(src).arg(dst).arg(mv->errorString()) << endl;
     }
 }
 
-void CopyFile(const QString & src, const QString & dst, bool nothrow)
+void CopyFile(const QString &src, const QString &dst, bool nothrow)
 {
-    KIO::FileCopyJob* copy = KIO::file_copy(QUrl::fromLocalFile(src), QUrl::fromLocalFile(dst));
+    KIO::FileCopyJob *copy = KIO::file_copy(QUrl::fromLocalFile(src), QUrl::fromLocalFile(dst));
     if (!copy->exec()) {
         if (!nothrow)
-            throw Error(i18n("Cannot copy %1 to %2: %3",
-                             src, dst,
-                             copy->errorString()));
+            throw Error(i18n("Cannot copy %1 to %2: %3", src, dst, copy->errorString()));
         else
-            Out(SYS_DIO | LOG_NOTICE) << QStringLiteral("Error : Cannot copy %1 to %2: %3")
-                                      .arg(src).arg(dst)
-                                      .arg(copy->errorString()) << endl;
-
+            Out(SYS_DIO | LOG_NOTICE) << QStringLiteral("Error : Cannot copy %1 to %2: %3").arg(src).arg(dst).arg(copy->errorString()) << endl;
     }
 }
 
-void CopyDir(const QString & src, const QString & dst, bool nothrow)
+void CopyDir(const QString &src, const QString &dst, bool nothrow)
 {
-    KIO::CopyJob* copy = KIO::copy(QUrl::fromLocalFile(src), QUrl::fromLocalFile(dst));
+    KIO::CopyJob *copy = KIO::copy(QUrl::fromLocalFile(src), QUrl::fromLocalFile(dst));
     if (!copy->exec()) {
         if (!nothrow)
-            throw Error(i18n("Cannot copy %1 to %2: %3",
-                             src, dst,
-                             copy->errorString()));
+            throw Error(i18n("Cannot copy %1 to %2: %3", src, dst, copy->errorString()));
         else
-            Out(SYS_DIO | LOG_NOTICE) << QStringLiteral("Error : Cannot copy %1 to %2: %3")
-                                      .arg(src).arg(dst)
-                                      .arg(copy->errorString()) << endl;
-
+            Out(SYS_DIO | LOG_NOTICE) << QStringLiteral("Error : Cannot copy %1 to %2: %3").arg(src).arg(dst).arg(copy->errorString()) << endl;
     }
 }
 
-bool Exists(const QString & url)
+bool Exists(const QString &url)
 {
     return QFile::exists(url);
 }
 
-static bool DelDir(const QString & fn)
+static bool DelDir(const QString &fn)
 {
     QDir d(fn);
     const QStringList subdirs = d.entryList(QDir::Dirs);
@@ -258,7 +238,7 @@ static bool DelDir(const QString & fn)
     return true;
 }
 
-void Delete(const QString & url, bool nothrow)
+void Delete(const QString &url, bool nothrow)
 {
     bool ok = true;
     // first see if it is a directory
@@ -277,23 +257,21 @@ void Delete(const QString & url, bool nothrow)
     }
 }
 
-void Touch(const QString & url, bool nothrow)
+void Touch(const QString &url, bool nothrow)
 {
     if (Exists(url))
         return;
 
-
     File fptr;
     if (!fptr.open(url, QStringLiteral("wb"))) {
         if (!nothrow)
             throw Error(i18n("Cannot create %1: %2", url, fptr.errorString()));
         else
-            Out(SYS_DIO | LOG_NOTICE) << "Error : Cannot create " << url << " : "
-                                      << fptr.errorString() << endl;
+            Out(SYS_DIO | LOG_NOTICE) << "Error : Cannot create " << url << " : " << fptr.errorString() << endl;
     }
 }
 
-Uint64 FileSize(const QString & url)
+Uint64 FileSize(const QString &url)
 {
     int ret = 0;
 #ifdef HAVE_STAT64
@@ -329,20 +307,19 @@ Uint64 FileSize(int fd)
 
 bool XfsPreallocate(int fd, Uint64 size)
 {
-    if (! platform_test_xfs_fd(fd)) {
+    if (!platform_test_xfs_fd(fd)) {
         return false;
     }
 
     xfs_flock64_t allocopt;
     allocopt.l_whence = 0;
     allocopt.l_start = 0;
-    allocopt.l_len  = size;
-
-    return (! static_cast<bool>(xfsctl(0, fd, XFS_IOC_RESVSP64, &allocopt)));
+    allocopt.l_len = size;
 
+    return (!static_cast<bool>(xfsctl(0, fd, XFS_IOC_RESVSP64, &allocopt)));
 }
 
-bool XfsPreallocate(const QString & path, Uint64 size)
+bool XfsPreallocate(const QString &path, Uint64 size)
 {
     int fd = ::open(QFile::encodeName(path).constData(), O_RDWR | O_LARGEFILE);
     if (fd < 0)
@@ -384,7 +361,7 @@ void TruncateFile(int fd, Uint64 size, bool quick)
     }
 }
 
-void TruncateFile(const QString & path, Uint64 size)
+void TruncateFile(const QString &path, Uint64 size)
 {
     int fd = ::open(QFile::encodeName(path).constData(), O_RDWR | O_LARGEFILE);
     if (fd < 0)
@@ -409,7 +386,7 @@ void SeekFile(int fd, Int64 off, int whence)
         throw Error(i18n("Cannot seek in file: %1", QString::fromUtf8(strerror(errno))));
 }
 
-bool FreeDiskSpace(const QString & path, Uint64 & bytes_free)
+bool FreeDiskSpace(const QString &path, Uint64 &bytes_free)
 {
 #ifdef HAVE_STATVFS
 #ifdef HAVE_STATVFS64
@@ -426,8 +403,7 @@ bool FreeDiskSpace(const QString & path, Uint64 & bytes_free)
         bytes_free = ((Uint64)stfs.f_bavail) * ((Uint64)stfs.f_frsize);
         return true;
     } else {
-        Out(SYS_GEN | LOG_DEBUG) << "Error : statvfs for " << path << " failed :  "
-                                 << QString::fromUtf8(strerror(errno)) << endl;
+        Out(SYS_GEN | LOG_DEBUG) << "Error : statvfs for " << path << " failed :  " << QString::fromUtf8(strerror(errno)) << endl;
 
         return false;
     }
@@ -447,11 +423,11 @@ bool FreeDiskSpace(const QString & path, Uint64 & bytes_free)
 #endif
 }
 
-bool FileNameToLong(const QString & path)
+bool FileNameToLong(const QString &path)
 {
     int length = 0;
     const QStringList names = path.split(QLatin1Char('/'));
-    for (const QString & s : names) {
+    for (const QString &s : names) {
         QByteArray encoded = QFile::encodeName(s);
         if (encoded.length() >= NAME_MAX)
             return true;
@@ -462,7 +438,7 @@ bool FileNameToLong(const QString & path)
     return length >= PATH_MAX;
 }
 
-static QString ShortenName(const QString & name, int extra_number)
+static QString ShortenName(const QString &name, int extra_number)
 {
     QFileInfo fi(name);
     QString ext = fi.suffix();
@@ -493,7 +469,7 @@ static QString ShortenName(const QString & name, int extra_number)
     return ret;
 }
 
-static QString ShortenPath(const QString & path, int extra_number)
+static QString ShortenPath(const QString &path, int extra_number)
 {
     int max_len = PATH_MAX;
     QByteArray encoded = QFile::encodeName(path);
@@ -531,15 +507,14 @@ static QString ShortenPath(const QString & path, int extra_number)
     return ret;
 }
 
-QString ShortenFileName(const QString & path, int extra_number)
+QString ShortenFileName(const QString &path, int extra_number)
 {
     QString assembled = QStringLiteral("/");
     const QStringList names = path.split(QLatin1Char('/'), Qt::SkipEmptyParts);
     int cnt = 0;
-    for (const QString& s : names) {
+    for (const QString &s : names) {
         QByteArray encoded = QFile::encodeName(s);
-        assembled += (encoded.length() < NAME_MAX) ? s
-                     : ShortenName(s, extra_number);
+        assembled += (encoded.length() < NAME_MAX) ? s : ShortenName(s, extra_number);
         if (cnt < names.count() - 1)
             assembled += QLatin1Char('/');
         cnt++;
@@ -553,8 +528,7 @@ QString ShortenFileName(const QString & path, int extra_number)
     return assembled;
 }
 
-
-Uint64 DiskUsage(const QString& filename)
+Uint64 DiskUsage(const QString &filename)
 {
     Uint64 ret = 0;
 #ifndef Q_WS_WIN
@@ -603,7 +577,7 @@ QSet<QString> AccessibleMountPoints()
 {
     QSet<QString> result;
 #ifdef Q_OS_LINUX
-    FILE* fptr = setmntent("/proc/mounts", "r");
+    FILE *fptr = setmntent("/proc/mounts", "r");
     if (!fptr)
         return result;
 
@@ -617,8 +591,8 @@ QSet<QString> AccessibleMountPoints()
 
 #else
     const QList<Solid::Device> devs = Solid::Device::listFromType(Solid::DeviceInterface::StorageAccess);
-    for (const Solid::Device& dev : devs) {
-        const Solid::StorageAccess* sa = dev.as<Solid::StorageAccess>();
+    for (const Solid::Device &dev : devs) {
+        const Solid::StorageAccess *sa = dev.as<Solid::StorageAccess>();
         if (!sa->filePath().isEmpty() && sa->isAccessible())
             result.insert(sa->filePath());
     }
@@ -626,11 +600,11 @@ QSet<QString> AccessibleMountPoints()
     return result;
 }
 
-QString MountPoint(const QString& path)
+QString MountPoint(const QString &path)
 {
     const QSet<QString> mount_points = AccessibleMountPoints();
     QString mount_point;
-    for (const QString & mp : mount_points) {
+    for (const QString &mp : mount_points) {
         if (path.startsWith(mp) && (mount_point.isEmpty() || mp.startsWith(mount_point))) {
             mount_point = mp;
         }
@@ -639,13 +613,12 @@ QString MountPoint(const QString& path)
     return mount_point;
 }
 
-
-bool IsMounted(const QString& mount_point)
+bool IsMounted(const QString &mount_point)
 {
     return AccessibleMountPoints().contains(mount_point);
 }
 
-QByteArray LoadFile(const QString& path)
+QByteArray LoadFile(const QString &path)
 {
     QFile fptr(path);
     if (fptr.open(QIODevice::ReadOnly))
